@@ -110,8 +110,8 @@ def main(args=None):
 # Optical Profiles
     logger.info("Section A: Reading the SCC files ")
     try:
-        dt_start_arr, alt_arr, prod_arr, prod_err_arr, metadata, wave = \
-            read_scc_db(files, end_fill = alphas)
+        dt_start_arr, alt_b_arr, alt_arr, prod_arr, prod_err_arr, metadata, wave = \
+            read_scc_db(files, end_fill = alphas/2.)
     
     except Exception as e:
         logger.error("Error while reading the SCC files ")
@@ -134,7 +134,7 @@ def main(args=None):
             rl_flag, bases, tops, wct, wct_err = \
                 feature_id(alt_arr[i], sig = prod_arr[i], sig_err = prod_err_arr[i],
                            alpha = alphas[i], snr_factor = snr_factor[i], 
-                           wct_peak_margin = wct_peak_margin[i], log = logger)
+                           wct_peak_margin = wct_peak_margin[i], floor = alt_b_arr[i], log = logger)
 
         except Exception as e:
             logger.error("Error while identifying layer boundaries ")
