@@ -14,7 +14,7 @@ import warnings
 
 warnings.filterwarnings("ignore")
 
-def feature_id(alt, sig, sig_err, alpha, snr_factor, wct_peak_margin, log):
+def feature_id(alt, sig, sig_err, alpha, snr_factor, wct_peak_margin, floor, log):
     
     bases = []
     tops = []
@@ -39,13 +39,13 @@ def feature_id(alt, sig, sig_err, alpha, snr_factor, wct_peak_margin, log):
     if tops_dtf.shape[0] > 0:
         # Combine bases and tops dataframes in a signle dataframe sorted by ascending index
         merged = combine(bases = bases_dtf, tops = tops_dtf)
-            
+
         # Keep only base-top pairsand the first top if it exists
         merged = match_layers(merged, snr_factor = snr_factor, 
                               wct_peak_margin = wct_peak_margin)
         
         # Split merged dataframe in bases/tops lists (lenght must be the same)
-        rl_flag, bases, tops = split(merged, floor = alt[0])
+        rl_flag, bases, tops = split(merged, floor = floor)
         
     wct[mask_sig] = np.nan
     wct_err[mask_sig_err] = np.nan
@@ -79,7 +79,7 @@ def geom_prop(rl_flag, bases, tops, alt, sig, log):
             
             sig_l = sig[(alt >= bases[i]) & (alt <= tops[i])]
             alt_l = alt[(alt >= bases[i]) & (alt <= tops[i])]
-
+            
             bases[i] = np.round(bases[i], decimals = 5) 
             tops[i] = np.round(tops[i], decimals = 5) 
 
@@ -87,7 +87,7 @@ def geom_prop(rl_flag, bases, tops, alt, sig, log):
                               np.trapz(sig_l, x = alt_l), decimals = 5)
             
             dpth[i] = np.round(np.trapz(sig_l, x = alt_l)/
-                               (tck[i]), decimals = 3)         
+                               (tck[i]), decimals = 9)         
             
             wgh[i] = np.round(np.trapz(sig_l, x = alt_l)/
                               (np.trapz(sig, x = alt)), decimals = 5)         
@@ -95,13 +95,14 @@ def geom_prop(rl_flag, bases, tops, alt, sig, log):
             mask_max = (sig_l == np.nanmax(sig_l))
 
             peak[i] = np.round(alt_l[mask_max][-1], decimals = 5)
-            psig[i] = np.round(sig_l[mask_max][-1], decimals = 3)
-            bsig[i] = np.round(sig_l[0], decimals = 3)
-            tsig[i] = np.round(sig_l[-1], decimals = 3)
-            msig[i] = np.round(np.min([bsig[i], tsig[i]]), decimals = 3)
+            psig[i] = np.round(sig_l[mask_max][-1], decimals = 9)
+            bsig[i] = np.round(sig_l[0], decimals = 9)
+            tsig[i] = np.round(sig_l[-1], decimals = 9)
+            msig[i] = np.round(np.min([bsig[i], tsig[i]]), decimals = 9)
             shrp[i] = np.round((psig[i] - np.max([bsig[i], tsig[i]])), 
-                               decimals = 3)
-            trnd[i] = np.round((tsig[i] - bsig[i]), decimals = 3)
+                               decimals = 9)
+            trnd[i] = np.round((tsig[i] - bsig[i]), decimals = 9)
+
 
         # Export to xarray Data Array, ensure there are layers left after removing the insignificant ones
         if len(bases) > 0:
